@@ -1,10 +1,12 @@
 I = iterpc(5, ordered=TRUE)
 expect_that(getnext(I)[3], equals(3))
+expect_that(getcurrent(I)[3], equals(3))
 expect_that(nrow(getall(I)), equals(getlength(I)))
 
 I = iterpc(3, labels=c("a","b","c"), ordered=TRUE)
 getnext(I)
 expect_that(getnext(I), equals(c("a","c","b")))
+expect_that(getcurrent(I), equals(c("a","c","b")))
 
 I = iterpc(c(2,1), labels=c("a","c"), ordered=TRUE)
 expect_that(nrow(getall(I)), equals(getlength(I)))
